@@ -1,6 +1,6 @@
-filter<-function(data,date.start=NULL,date.end=NULL,shw=NULL,lat.low=NULL,lat.up=NULL,long.low=NULL,long.up=NULL, 
-fname=NULL,lname=NULL,site=NULL,country=NULL,mag.low=NULL,mag.up=NULL,P.low=NULL,P.up=NULL,sol.low=NULL,sol.up=NULL,
-h.low=NULL,h.up=NULL,r=NULL,C=NULL)
+filter<-function(data,date.start=NULL,date.end=NULL,shw=NULL,lat.low=-90,lat.up=90,long.low=-180,long.up=180, 
+fname=NULL,lname=NULL,site=NULL,country=NULL,mag.low=1,mag.up=8,P.low=0,P.up=90,sol.low=NULL,sol.up=NULL,
+h.low=0,h.up=90,r=NULL,C=NULL)
 {
    data.select<-data
 
@@ -13,7 +13,7 @@ h.low=NULL,h.up=NULL,r=NULL,C=NULL)
    if(!is.null(fname) && !is.null(lname)) 
       data.select<-filter.obsname(data.select,fname,lname)
  
-   if(!is.null(lat.low) && !is.null(lat.up) && !is.null(long.low) && !is.null(long.up))
+   if(lat.low!=-90 || lat.up!=90 || long.low!=-180 || long.up!=180)
       data.select<-filter.gc(data.select,long.low,long.up,lat.low,lat.up)
   
    if(!is.null(site)) 
@@ -22,16 +22,16 @@ h.low=NULL,h.up=NULL,r=NULL,C=NULL)
    if(!is.null(country)) 
       data.select<-filter.country(data.select,country)
  
-   if(!is.null(mag.low) && !is.null(mag.up)) 
+   if(mag.low!=1 || mag.up!=8) 
       data.select<-filter.mag(data.select,mag.low,mag.up)
 
-   if(!is.null(P.low) && !is.null(P.up)) 
+   if(P.low!=0 || P.up!=90) 
       data.select<-filter.P(data.select,P.low,P.up)
  
    if(!is.null(sol.low) && !is.null(sol.up)) 
       data.select<-filter.sol(data.select,sol.low,sol.up)
 
-   if(!is.null(h.low) && !is.null(h.up)) 
+   if(!is.null(shw) && (h.low!=0 || h.up!=90)) 
       data.select<-filter.h(data.select,shw,h.low,h.up)
    
    if(!is.null(r) && !is.null(C))
